==> jc-1.4.0.tar.gz: javax/swing/plaf/IconUIResource.h <==
// public class javax.swing.plaf.IconUIResource

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 8fa0f15b197becf5 javax_swing_plaf_IconUIResource

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_IconUIResource_H_
#define _JC_javax_swing_plaf_IconUIResource_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_Icon$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_IconUIResource$sub_refs	_jc_javax_swing_plaf_IconUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_IconUIResource$sub_nonrefs	_jc_javax_swing_plaf_IconUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_IconUIResource$refs	_jc_javax_swing_plaf_IconUIResource$refs;
typedef struct _jc_javax_swing_plaf_IconUIResource$nonrefs	_jc_javax_swing_plaf_IconUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_IconUIResource$object	_jc_javax_swing_plaf_IconUIResource$object;

typedef struct _jc_javax_swing_plaf_IconUIResource$fields_struct	_jc_javax_swing_plaf_IconUIResource$fields_struct;
typedef const struct _jc_javax_swing_plaf_IconUIResource$vmethods	_jc_javax_swing_plaf_IconUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_IconUIResource$vtable	_jc_javax_swing_plaf_IconUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_IconUIResource$vtype	_jc_javax_swing_plaf_IconUIResource$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_IconUIResource$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_IconUIResource$fields_struct _jc_javax_swing_plaf_IconUIResource$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_IconUIResource$method$_init$0fd162b98f069aeb(_jc_env *, struct _jc_javax_swing_plaf_IconUIResource$object *, struct _jc_object *);

// Virtual methods
extern jint _jc_javax_swing_plaf_IconUIResource$method$getIconHeight$50a8d095671b871d(_jc_env *, struct _jc_javax_swing_plaf_IconUIResource$object *);
extern jint _jc_javax_swing_plaf_IconUIResource$method$getIconWidth$e4e0e0a5d8773e91(_jc_env *, struct _jc_javax_swing_plaf_IconUIResource$object *);
extern void _jc_javax_swing_plaf_IconUIResource$method$paintIcon$ec942e304ba768a4(_jc_env *, struct _jc_javax_swing_plaf_IconUIResource$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_IconUIResource$method_info$getIconHeight$50a8d095671b871d;
extern _jc_method _jc_javax_swing_plaf_IconUIResource$method_info$getIconWidth$e4e0e0a5d8773e91;
extern _jc_method _jc_javax_swing_plaf_IconUIResource$method_info$paintIcon$ec942e304ba768a4;

// Virtual methods structure
struct _jc_javax_swing_plaf_IconUIResource$vmethods {
	jint	(*getIconHeight$50a8d095671b871d)(_jc_env *, struct _jc_javax_swing_plaf_IconUIResource$object *);
	jint	(*getIconWidth$e4e0e0a5d8773e91)(_jc_env *, struct _jc_javax_swing_plaf_IconUIResource$object *);
	void	(*paintIcon$ec942e304ba768a4)(_jc_env *, struct _jc_javax_swing_plaf_IconUIResource$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint);
};

// Vtable
struct _jc_javax_swing_plaf_IconUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_IconUIResource$vmethods	javax_swing_plaf_IconUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_IconUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_IconUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_IconUIResource$sub_refs {
	struct _jc_object	*delegate;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_IconUIResource$refs {
    _jc_javax_swing_plaf_IconUIResource$sub_refs	javax_swing_plaf_IconUIResource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_IconUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_IconUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_IconUIResource$sub_nonrefs	javax_swing_plaf_IconUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_IconUIResource$object {
	_jc_javax_swing_plaf_IconUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_IconUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_IconUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_IconUIResource$vtype _jc_javax_swing_plaf_IconUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_IconUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_IconUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_IconUIResource_H_ */

==> jc-1.4.6.tar.gz: javax/swing/plaf/IconUIResource.h <==
// public class javax.swing.plaf.IconUIResource

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 8fa0f15b197becf5 javax_swing_plaf_IconUIResource

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_swing_plaf_IconUIResource_H_
#define _JC_javax_swing_plaf_IconUIResource_H_

// Forward structure declarations
struct _jc_java_awt_Component$object;
struct _jc_java_awt_Graphics$object;
struct _jc_java_lang_Class$object;
struct _jc_javax_swing_Icon$object;

// Typedefs
typedef struct _jc_javax_swing_plaf_IconUIResource$sub_refs	_jc_javax_swing_plaf_IconUIResource$sub_refs;
typedef struct _jc_javax_swing_plaf_IconUIResource$sub_nonrefs	_jc_javax_swing_plaf_IconUIResource$sub_nonrefs;
typedef struct _jc_javax_swing_plaf_IconUIResource$refs	_jc_javax_swing_plaf_IconUIResource$refs;
typedef struct _jc_javax_swing_plaf_IconUIResource$nonrefs	_jc_javax_swing_plaf_IconUIResource$nonrefs;
typedef struct _jc_javax_swing_plaf_IconUIResource$object	_jc_javax_swing_plaf_IconUIResource$object;

typedef struct _jc_javax_swing_plaf_IconUIResource$fields_struct	_jc_javax_swing_plaf_IconUIResource$fields_struct;
typedef const struct _jc_javax_swing_plaf_IconUIResource$vmethods	_jc_javax_swing_plaf_IconUIResource$vmethods;
typedef const struct _jc_javax_swing_plaf_IconUIResource$vtable	_jc_javax_swing_plaf_IconUIResource$vtable;
typedef const struct _jc_javax_swing_plaf_IconUIResource$vtype	_jc_javax_swing_plaf_IconUIResource$vtype;

// Class fields structure
struct _jc_javax_swing_plaf_IconUIResource$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_plaf_IconUIResource$fields_struct _jc_javax_swing_plaf_IconUIResource$class_fields;

// Constructors
extern void _jc_javax_swing_plaf_IconUIResource$method$_init$0fd162b98f069aeb(_jc_env *, struct _jc_javax_swing_plaf_IconUIResource$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_javax_swing_plaf_IconUIResource$method$getIconHeight$50a8d095671b871d(_jc_env *, struct _jc_javax_swing_plaf_IconUIResource$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_swing_plaf_IconUIResource$method$getIconWidth$e4e0e0a5d8773e91(_jc_env *, struct _jc_javax_swing_plaf_IconUIResource$object *) _JC_JCNI_ATTR;
extern void _jc_javax_swing_plaf_IconUIResource$method$paintIcon$ec942e304ba768a4(_jc_env *, struct _jc_javax_swing_plaf_IconUIResource$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_plaf_IconUIResource$method_info$getIconHeight$50a8d095671b871d;
extern _jc_method _jc_javax_swing_plaf_IconUIResource$method_info$getIconWidth$e4e0e0a5d8773e91;
extern _jc_method _jc_javax_swing_plaf_IconUIResource$method_info$paintIcon$ec942e304ba768a4;

// Virtual methods structure
struct _jc_javax_swing_plaf_IconUIResource$vmethods {
	jint	(*getIconHeight$50a8d095671b871d)(_jc_env *, struct _jc_javax_swing_plaf_IconUIResource$object *) _JC_JCNI_ATTR;
	jint	(*getIconWidth$e4e0e0a5d8773e91)(_jc_env *, struct _jc_javax_swing_plaf_IconUIResource$object *) _JC_JCNI_ATTR;
	void	(*paintIcon$ec942e304ba768a4)(_jc_env *, struct _jc_javax_swing_plaf_IconUIResource$object *, struct _jc_java_awt_Component$object *, struct _jc_java_awt_Graphics$object *, jint, jint) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_plaf_IconUIResource$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_plaf_IconUIResource$vmethods	javax_swing_plaf_IconUIResource;
};

// Vtype
struct _jc_javax_swing_plaf_IconUIResource$vtype {
	_jc_type			type;
	_jc_javax_swing_plaf_IconUIResource$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_plaf_IconUIResource$sub_refs {
	struct _jc_object	*delegate;
};

// Reference instance fields (object)
struct _jc_javax_swing_plaf_IconUIResource$refs {
    _jc_javax_swing_plaf_IconUIResource$sub_refs	javax_swing_plaf_IconUIResource;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_plaf_IconUIResource$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_plaf_IconUIResource$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_plaf_IconUIResource$sub_nonrefs	javax_swing_plaf_IconUIResource;
};

// Object instance structure
struct _jc_javax_swing_plaf_IconUIResource$object {
	_jc_javax_swing_plaf_IconUIResource$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_plaf_IconUIResource$vtype	*vtype;
	_jc_javax_swing_plaf_IconUIResource$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_plaf_IconUIResource$vtype _jc_javax_swing_plaf_IconUIResource$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_plaf_IconUIResource, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_plaf_IconUIResource$class_object;

#endif	/* _JC_javax_swing_plaf_IconUIResource_H_ */
